@@ -101,7 +101,7 @@ class FirefoxProfile(object):
     #Public Methods
     def set_preference(self, key, value): 
         """ sets the preference that we want in the profile."""
-        self.default_preferences[key] = str(value)
+        self.default_preferences[key] = repr(value)
 
     def add_extension(self, extension=WEBDRIVER_EXT):
         self._install_extension(extension)
