@@ -59,7 +59,7 @@ class WebElement(object):
         if resp['value'] is None:
             attributeValue = None
         else:
-            attributeValue = str(resp['value'])
+            attributeValue = unicode(resp['value'])
             if type(resp['value']) is bool:
                 attributeValue = attributeValue.lower()
 
